Wagtail Flexible Forms
======================

Wagtail flexible forms provides a more robust StreamField-based form builder (sometimes called a "StreamForm") with similar functionality to `wagtail.contrib.forms`.


Installation & Usage
--------------------

Read the [documentation](https://docs.coderedcorp.com/wagtail-flexible-forms/), which includes a video demo and example project.


History & Future of This Project
--------------------------------

This project was [originally developed by Bertrand Bordage of NoriPyt](https://www.kickstarter.com/projects/noripyt/wagtails-first-hatch) with the intention of being merged into Wagtail as `wagtail.contrib.stream_forms`.

In 2019, CodeRed used the code as part of Wagtail CRX (`coderedcms`) to and began providing ongoing maintenance as part of that package.

In 2021 CodeRed took ownership of this repository, and with renewed interest from the Wagtail community, in 2025 de-vendored the code from `coderedcms` and backported the past 6 years of changes to produce a stable version of `wagtail-flexible-forms` as its own pip package.

Stay tuned in 2025 as we work to add documentation, examples, and unit tests with the goal of eventually merging the package into Wagtail as the official "stream forms" implementation. It is a fantastic package and we are excited to be investing in it to share with the Wagtail community!
